<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output xml:space="preserve" indent="yes"/>
<xsl:template match="/">
    <html>
        <head>
            <title>Uniforge - <xsl:value-of select="//character/@name"/></title>
            <style type="text/css">
                td { font-family: sans-serif; 
                       font-size: 10pt}
                th { font-family: sans-serif;
                       font-size: 12pt}
            </style>
        </head>
        
        <body>
        <p>
        <table border="0">
        <tr>
            <th colspan="1" align="left"><strong>Name: </strong><xsl:value-of select="/character/@name"/></th>
            <xsl:if test="count(//player/@name) &gt; 0">
                <th colspan="2" align="left"><strong>Player: </strong><xsl:value-of select="//player/@name"/></th></xsl:if>
        </tr>
        <tr>
            <xsl:if test="count(//concept/@concept) &gt; 0">
                <td><strong>Concept: </strong><xsl:value-of select="//concept/@concept"/></td></xsl:if>
            <xsl:if test="count(//association/@name) &gt; 0">
                <td><strong>Association </strong><xsl:value-of select="//association/@name"/></td>
                <td colspan="2"><em><xsl:value-of select="//association"/></em></td></xsl:if>
        </tr>
        <tr>
            <td><strong>Character type: </strong><xsl:value-of select="//charactertype/@choice"/></td>
        </tr>
        </table>
        </p>
        <p>
        <table border="0">
        <tr>
            <th align="center" bgcolor="silver" colspan="4"><strong>Description</strong></th>
        </tr>
        <tr>
            <td><strong>Gender: </strong><xsl:value-of select="//description/@gender"/></td>
            <td><strong>Age: </strong><xsl:value-of select="//description/@age"/></td>
            <td colspan="2"><strong>Hair: </strong><xsl:value-of select="//description/@hair"/></td>
        </tr>
        <tr>
            <td><strong>Race: </strong><xsl:value-of select="//description/@race"/></td>
            <td><strong>Height: </strong><xsl:value-of select="//description/@height"/></td>
            <td><strong>Weight: </strong><xsl:value-of select="//description/@weight"/></td>
            <td><strong>Eyes: </strong><xsl:value-of select="//description/@eyes"/></td>
        </tr>
        </table>
        </p>
        <p>
        <table border="0">
        <tr>
            <th colspan="2" bgcolor="silver" align="center"><strong>Physical Attributes</strong></th>
            <th colspan="2" bgcolor="silver" align="center"><strong>Mental Attributes</strong></th>
            <th width="50"></th>
            <th colspan="4" bgcolor="silver" align="center"><strong>Secondary Attributes</strong></th>
        </tr>
        <tr>
            <td><strong>Strength: </strong></td>
            <td><xsl:value-of select="//strength/@total"/></td>
            <td><strong>Intelligence: </strong></td>
            <td><xsl:value-of select="//intelligence/@total"/></td>
            <td width="50"></td>
            <td><strong>Life Points: </strong></td>
            <td><xsl:value-of select="//lifepoints/@total"/></td>
            <xsl:if test="count(//dramapoints) = 0">
                <td><strong>Endurance Points: </strong></td>
                <td><xsl:value-of select="//endurance/@total"/></td>
            </xsl:if>
        </tr>
        <tr>
            <td><strong>Dexterity: </strong></td>
            <td><xsl:value-of select="//dexterity/@total"/></td>
            <td><strong>Perception: </strong></td>
            <td><xsl:value-of select="//perception/@total"/></td>
            <td width="50"></td>
            <xsl:if test="count(//dramapoints) = 0">
                <td><strong>Speed: </strong></td>
                <td><xsl:value-of select="//speed/@total"/></td>
                <td><strong>Essence Pool: </strong></td>
                <td><xsl:value-of select="//essence/@total"/></td>
            </xsl:if>
        </tr>
        <tr>
            <td><strong>Consitution: </strong></td>
            <td><xsl:value-of select="//constitution/@total"/></td>
            <td><strong>Willpower: </strong></td>
            <td><xsl:value-of select="//willpower/@total"/></td>
            <td width="50"></td>
            <xsl:if test="//dramapoints/@points &gt; 0">
                <td><strong>Drama Points: </strong></td>
                <td> <xsl:value-of select="//dramapoints/@points"/></td>
            </xsl:if>
            <xsl:if test="count(//extrastats) &gt; 0">
                <td colspan="2"><xsl:value-of select="//extrastats"/></td></xsl:if>
        </tr>
        </table>
        </p>
        <xsl:if test="count(//quality) &gt; 0">
            <p>
            <table>
            <tr>
                <th colspan="5" bgcolor="silver" align="center">
                    <strong>Qualities and Drawbacks</strong></th>
            </tr>
            <tr>
                <th align="left"><strong>Quality or Drawback</strong></th>
                <th align="center"><strong>Level</strong></th>
                <th align="center"><strong>Cost</strong></th>
                <th align="center"><strong>XPs</strong></th>
                <th align="left"><strong>Notes</strong></th>
            </tr>
            <xsl:for-each select="//quality">
            <tr>
                <td><xsl:value-of select="@col0"/></td>
                <td align="center"><xsl:value-of select="@col1"/></td>
                <td align="center"><xsl:value-of select="@col2"/></td>
                <td align="center"><xsl:value-of select="@col3"/></td>
                <td><em><xsl:value-of select="."/></em></td>
            </tr>
            </xsl:for-each>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//skill) &gt; 0">
            <p>
            <table>
            <tr>
                <th colspan="5" bgcolor="silver" align="center">
                    <strong>Skills</strong></th>
            </tr>
            <tr>
                <th align="left"><strong>Skill</strong></th>
                <th align="center"><strong>Level</strong></th>
                <th align="center"><strong>Cost</strong></th>
                <th align="center"><strong>XPs</strong></th>
                <th align="left"><strong>Notes</strong></th>
            </tr>
            <xsl:for-each select="//skill">
            <tr>
                <td><xsl:value-of select="@col0"/></td>
                <td align="center"><xsl:value-of select="@col1"/></td>
                <td align="center"><xsl:value-of select="@col2"/></td>
                <td align="center"><xsl:value-of select="@col3"/></td>
                <td><em><xsl:value-of select="."/></em></td>
            </tr>
            </xsl:for-each>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//martialmaneuver) &gt; 0">
            <p>
            <table border="0">
                <tr>
                    <th bgcolor="silver" align="center" colspan="2"><strong>Combat Moves</strong></th>
                </tr>
                <xsl:for-each select="//martialmaneuver">
                <tr>
                    <td><xsl:value-of select="@name"/></td>
                    <td><xsl:value-of select="@value"/></td>
                </tr>
                </xsl:for-each>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//visualization) &gt; 0">
            <p>
                <table border="0">
                    <tr>
                        <th bgcolor="silver" align="center" colspan="2"><strong>Visualizations</strong></th>
                    </tr>
                    <xsl:for-each select="//visualization">
                        <tr>
                            <td><xsl:value-of select="@name"/></td>
                            <td><xsl:value-of select="@value"/></td>
                        </tr>
                    </xsl:for-each>
                </table>
            </p>
        </xsl:if>
            <xsl:if test="count(//meta) &gt; 0">
                <p>
                    <table>
                        <tr>
                            <th colspan="5" bgcolor="silver" align="center">
                                <strong>Metaphysics</strong></th>
                        </tr>
                        <tr>
                            <th align="left"><strong>Meta</strong></th>
                            <th align="center"><strong>Level</strong></th>
                            <th align="center"><strong>Cost</strong></th>
                            <th align="center"><strong>XPs</strong></th>
                            <th align="left"><strong>Notes</strong></th>
                        </tr>
                        <xsl:for-each select="//meta">
                            <tr>
                                <td><xsl:value-of select="@col0"/></td>
                                <td align="center"><xsl:value-of select="@col1"/></td>
                                <td align="center"><xsl:value-of select="@col2"/></td>
                                <td align="center"><xsl:value-of select="@col3"/></td>
                                <td><em><xsl:value-of select="."/></em></td>
                            </tr>
                        </xsl:for-each>
                    </table>
                </p>
            </xsl:if>
            <xsl:if test="count(//altforms) &gt; 0">
            <p>
            <table border="0">
            <tr>
                <th bgcolor="silver" align="center"><strong>Alternate Forms</strong></th>
            </tr>
            <tr>
                <td>
                    <xsl:for-each select="//altforms/p">
                        <xsl:value-of select="."/><br />
                    </xsl:for-each>
                </td>
            </tr>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//equipment) &gt; 0">
            <p>
            <table border="0">
            <tr>
                <th bgcolor="silver" align="center"><strong>Equipment</strong></th>
            </tr>
            <tr>
                <td>
                    <xsl:for-each select="//equipment/p">
                        <xsl:value-of select="."/><br />
                    </xsl:for-each>
                </td>
            </tr>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//notes) &gt; 0">
            <p>
            <table border="0">
            <tr>
                <th bgcolor="silver" align="center"><strong>Notes</strong></th>
            </tr>
            <tr>
                <td>
                    <xsl:for-each select="//notes/p">
                        <xsl:value-of select="."/><br />
                    </xsl:for-each>
                </td>
            </tr>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//history) &gt; 0">
            <p>
            <table border="0">
            <tr>
                <th bgcolor="silver" align="center"><strong>History</strong></th>
            </tr>
            <tr>
                <td>
                    <xsl:for-each select="//history/p">    
                        <xsl:value-of select="."/><br />
                    </xsl:for-each>
                </td>
            </tr>
            </table>
            </p>
        </xsl:if>
        <xsl:if test="count(//contacts) &gt; 0">
            <p>
            <table border="0">
            <tr>
                <th bgcolor="silver" align="center"><strong>Contacts</strong></th>
            </tr>
            <tr>
                <td>
                    <xsl:for-each select="//contacts/p">
                        <xsl:value-of select="."/><br />
                    </xsl:for-each>
                </td>
            </tr>
            </table>
            </p>
        </xsl:if>
        <p>
        <table border="0">
        <tr>
            <td align="right"><em>Character Sheet by <xsl:value-of select="/character/@UniForgeVersion"/>. 
                Last Modified <xsl:value-of select="/character/@LastChange"/></em></td>
        </tr>
        </table>
        </p>
        </body>
    </html>
</xsl:template>
</xsl:stylesheet>
